@@ -117,8 +117,8 @@
 #' layout object depending on the value of `return`
 #'
 #' @examples
-#' data(iris_clusts)
-#' clustree(iris_clusts, prefix = "K")
+#' data(nba_clusts)
+#' clustree(nba_clusts, prefix = "K")
 #'
 #' @export
 clustree <- function (x, ...) {
@@ -208,7 +208,9 @@ clustree.matrix <- function(x, prefix,
              call. = FALSE)
     }
 
-    x <- x[, order(as.numeric(res_clean))]
+    res_order <- order(as.numeric(res_clean))
+    x <- x[, res_order]
+    res_clean <- res_clean[res_order]
 
     if (!(is.null(metadata))) {
         metadata_names <- make.names(colnames(metadata))
@@ -396,14 +398,22 @@ clustree.SingleCellExperiment <- function(x, prefix, exprs = "counts", ...) {
     }
 
     args <- list(...)
-    for (node_aes in c("node_colour", "node_size", "node_alpha")) {
-        if (node_aes %in% names(args)) {
-            node_aes_value <- args[[node_aes]]
-            if (node_aes_value %in% rownames(x)) {
-                aes_name <- paste0(exprs, "_", node_aes_value)
-                x@colData[aes_name] <- exprs_mat[node_aes_value, ]
-                args[[node_aes]] <- aes_name
+    node_aes_sel <- c("node_colour", "node_size", "node_alpha")
+    node_aes_sel <- node_aes_sel[node_aes_sel %in% names(args)]
+    for (node_aes in node_aes_sel) {
+        node_aes_value <- args[[node_aes]]
+        if (node_aes_value %in% rownames(x)) {
+            node_aes_name <- make.names(node_aes_value)
+            if (node_aes_value != node_aes_name) {
+                warning(
+                    "The feature name ", node_aes_value,
+                    " will be converted to ", node_aes_name,
+                    call. = FALSE
+                )
             }
+            aes_name <- paste0(exprs, "_", node_aes_name)
+            x@colData[aes_name] <- exprs_mat[node_aes_value, ]
+            args[[node_aes]] <- aes_name
         }
     }
 
@@ -485,16 +495,23 @@ clustree.Seurat <- function(x, prefix = paste0(assay, "_snn_res."),
 
     exprs <- match.arg(arg = exprs)
     args <- list(...)
-    gene_names <- rownames(x = x)
-    for (node_aes in c("node_colour", "node_size", "node_alpha")) {
-        if (node_aes %in% names(x = args)) {
-            node_aes_value <- args[[node_aes]]
-            if (node_aes_value %in% gene_names) {
-                aes_name <- paste0(exprs, "_", node_aes_value)
-                x[[aes_name]] <- Seurat::FetchData(x, vars = node_aes_value,
-                                                   slot = exprs)
-                args[[node_aes]] <- aes_name
+    node_aes_sel <- c("node_colour", "node_size", "node_alpha")
+    node_aes_sel <- node_aes_sel[node_aes_sel %in% names(args)]
+    for (node_aes in node_aes_sel) {
+        node_aes_value <- args[[node_aes]]
+        if (node_aes_value %in% rownames(x)) {
+            node_aes_name <- make.names(node_aes_value)
+            if (node_aes_value != node_aes_name) {
+                warning(
+                    "The feature name ", node_aes_value,
+                    " will be converted to ", node_aes_name,
+                    call. = FALSE
+                )
             }
+            aes_name <- paste0(exprs, "_", node_aes_name)
+            x[[aes_name]] <- Seurat::FetchData(x, vars = node_aes_value,
+                                               slot = exprs)
+            args[[node_aes]] <- aes_name
         }
     }
 
